@@ -869,11 +869,11 @@ class CameraDevice(Protocol):
     async def disconnect(self) -> None: ...
 
     @overload
-    async def get_frames(
+    def get_frames(
         self, frame_type: Literal["video"], options: Optional[ImageOptions] = None
     ) -> AsyncGenerator[VideoFrame, None]: ...
     @overload
-    async def get_frames(
+    def get_frames(
         self, frame_type: Literal["motion"], options: Optional[ImageOptions] = None
     ) -> AsyncGenerator[MotionFrame, None]: ...
 
